/**
 * @typedef {any} CodeMirror A codemirror instance
 */
/**
 * A binding that binds a YText to a CodeMirror editor.
 *
 * @example
 *   const ytext = ydocument.define('codemirror', Y.Text)
 *   const editor = new CodeMirror(document.querySelector('#container'), {
 *     mode: 'javascript',
 *     lineNumbers: true
 *   })
 *   const binding = new CodeMirrorBinding(ytext, editor)
 *
 */
export class CodeMirrorBinding {
    /**
     * @param {Y.Text} textType
     * @param {CodeMirror} codeMirror
     * @param {any} [awareness]
     */
    constructor(textType: Y.Text, codeMirror: any, awareness?: any);
    type: Y.Text;
    target: any;
    awareness: any;
    /**
     * @private
     */
    private _mux;
    _typeObserver: (event: any) => void;
    _targetObserver: (_: any, change: any) => void;
    _cursors: Map<any, any>;
    _awarenessListener: (event: any) => void;
    _cursorListener: () => void;
    _blurListeer: () => any;
    destroy(): void;
}
/**
 * A codemirror instance
 */
export type CodeMirror = any;
import * as Y from "yjs";
